@@ -4,9 +4,9 @@ unit class Net::ZMQ::Context is repr('CPointer');
 use Net::ZMQ::Util;
 
 # ZMQ_EXPORT void *zmq_init (int io_threads);
-my sub zmq_init(int --> Net::ZMQ::Context) is native('libzmq') { * }
+my sub zmq_init(int32 --> Net::ZMQ::Context) is native('zmq',v5) { * }
 # ZMQ_EXPORT int zmq_term (void *context);
-my sub zmq_term(Net::ZMQ::Context --> int) is native('libzmq') { * }
+my sub zmq_term(Net::ZMQ::Context --> int32) is native('zmq',v5) { * }
 
 # TODO: What's a sane default number of threads?
 method new(:$threads = 1) {
